==> aidlab_sdk-0.0.1.tar.gz: android/src/main/kotlin/com/aidlab/aidlab_sdk/AidlabBluetoothManager.kt <==
package com.aidlab.aidlab_sdk

import android.content.Context
import android.os.Handler
import android.os.Looper
import android.util.Log
import com.aidlab.sdk.communication.Aidlab
import com.aidlab.sdk.communication.AidlabSDK
import com.aidlab.sdk.communication.AidlabSDKDelegate
import java.util.*


object AidlabBluetoothManager : AidlabSDKDelegate {

    private var initialized = false
    private lateinit var aidlabSDK: AidlabSDK
    private val detectedAidlabs = LinkedList<Aidlab>()

    var listener: AidlabFlutter.PlatformAidlabSdkDelegate? = null

    fun init(context: Context) {
        if(initialized) return
        initialized = true

        Handler(Looper.getMainLooper()).post {
            aidlabSDK = AidlabSDK(context, this)
        }
    }

    fun startScan() {
        aidlabSDK.scanForDevices()
        detectedAidlabs.clear()
    }

    fun stopScan() {
        aidlabSDK.stopDeviceScan()
    }

    fun addressToAidlab(address: String): Aidlab {
        return detectedAidlabs.find { it.address() == address }
                ?: throw IllegalStateException("Address not found in detected aidlabs")
    }

    override fun onAidlabDetected(aidlab: Aidlab, rssi: Int) {
        detectedAidlabs.add(aidlab)

        listener?.onAidlabDetected(AidlabFlutter.AidlabDetectedEvent().apply {
            address = aidlab.address()
        }) {}
    }

    override fun onScanFailed(errorCode: Int) {
        listener?.onScanFailed(AidlabFlutter.ScanFailedEvent().apply {
            this.errorCode = errorCode.toLong()
        }) {}
    }

    override fun onBluetoothStarted() {
        listener?.onBluetoothStarted(AidlabFlutter.EmptyEvent()) {}
    }
    override fun onDeviceScanStarted() {
        listener?.onDeviceScanStarted(AidlabFlutter.EmptyEvent()) {}
    }
    override fun onDeviceScanStopped() {
        listener?.onDeviceScanStopped(AidlabFlutter.EmptyEvent()) {}
    }
}

==> aidlab_sdk-0.0.3.tar.gz: android/src/main/kotlin/com/aidlab/aidlab_sdk/AidlabBluetoothManager.kt <==
package com.aidlab.aidlab_sdk

import android.content.Context
import android.os.Handler
import android.os.Looper
import android.util.Log
import com.aidlab.sdk.communication.*
import java.util.*


object AidlabBluetoothManager : AidlabSDKDelegate {

    private var initialized = false
    private lateinit var aidlabSDK: AidlabSDK
    private val detectedAidlabs = LinkedList<Aidlab>()
    var lastConnectedAidlab: Aidlab? = null
        private set

    var listener: AidlabFlutter.PlatformAidlabSdkDelegate? = null

    fun init(context: Context) {
        if(initialized) return
        initialized = true

        Handler(Looper.getMainLooper()).post {
            aidlabSDK = AidlabSDK(context, this)
        }
    }

    fun startScan() {
        aidlabSDK.scanForDevices()
        detectedAidlabs.clear()
    }

    fun stopScan() {
        aidlabSDK.stopDeviceScan()
    }

    fun connect(address: String, signals: EnumSet<Signal>, aidlabDelegate: AidlabDelegate) {
        stopScan()
        val aidlab = addressToAidlab(address)
        lastConnectedAidlab = aidlab
        aidlab.connect(signals, false, aidlabDelegate)
    }

    fun addressToAidlab(address: String): Aidlab {
        return detectedAidlabs.find { it.address() == address }
                ?: throw IllegalStateException("Address not found in detected aidlabs")
    }

    override fun onAidlabDetected(aidlab: Aidlab, rssi: Int) {
        detectedAidlabs.add(aidlab)

        listener?.onAidlabDetected(AidlabFlutter.AidlabDetectedEvent().apply {
            address = aidlab.address()
        }) {}
    }

    override fun onScanFailed(errorCode: Int) {
        listener?.onScanFailed(AidlabFlutter.ScanFailedEvent().apply {
            this.errorCode = errorCode.toLong()
        }) {}
    }

    override fun onBluetoothStarted() {
        listener?.onBluetoothStarted(AidlabFlutter.EmptyEvent()) {}
    }
    override fun onDeviceScanStarted() {
        listener?.onDeviceScanStarted(AidlabFlutter.EmptyEvent()) {}
    }
    override fun onDeviceScanStopped() {
        listener?.onDeviceScanStopped(AidlabFlutter.EmptyEvent()) {}
    }
}
